Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(223)

Unified Diff: src/spaces.cc

Issue 385163005: Some fixes to avoid breakages when enabling out-of-line constant pools. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Add an oxford comma. Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/objects.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/spaces.cc
diff --git a/src/spaces.cc b/src/spaces.cc
index e7cb8ccf85254003af635e44c2fe81d582e2b926..6f67066b9980d911c703f27b64b4b4a970fc6556 100644
--- a/src/spaces.cc
+++ b/src/spaces.cc
@@ -3062,10 +3062,12 @@ void LargeObjectSpace::Verify() {
// We have only code, sequential strings, external strings
// (sequential strings that have been morphed into external
// strings), fixed arrays, and byte arrays in large object space.
CHECK(object->IsCode() || object->IsSeqString() ||
- object->IsExternalString() || object->IsFixedArray() ||
- object->IsFixedDoubleArray() || object->IsByteArray());
+ object->IsExternalString() || object->IsFixedArray() ||
+ object->IsFixedDoubleArray() || object->IsByteArray() ||
+ object->IsConstantPoolArray());
// The object itself should look OK.
object->ObjectVerify();
« no previous file with comments | « src/objects.cc ('k') | no next file » | no next file with comments »
@@ -3062,10 +3062,12 @@ void LargeObjectSpace::Verify() {
// We have only code, sequential strings, external strings
// (sequential strings that have been morphed into external
- // strings), fixed arrays, and byte arrays in large object space.
+ // strings), fixed arrays, byte arrays, and constant pool arrays in the
+ // large object space.
CHECK(object->IsCode() || object->IsSeqString() ||

Powered by Google App Engine
This is Rietveld 408576698